%%
%% This is file `atari.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% umlaute.dtx  (with options: `atari')
%% 
%% Copyright (C) 1994-2006 Axel Sommerfeldt (caption@sommerfee.de)
%% 
%% --------------------------------------------------------------------------
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2003/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% This Current Maintainer of this work is Axel Sommerfeldt.
%% 
%% This work consists of the files umlaute.ins, umlaute.dtx
%% and the derived files umlaute.sty, atari.def, pc850.def,
%% isolatin.def, mac.def, and roman8.def.
%% 
\ProvidesFile{atari.def}[2006/01/29 v2.1 Input encoding file (AS)]
\makeatletter
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textonehalf}{\ensuremath{\frac12}}
\ProvideTextCommandDefault{\textonequarter}{\ensuremath{\frac14}}
\ProvideTextCommandDefault{\textthreequarters}{\ensuremath{\frac34}}
\ProvideTextCommandDefault{\texttrademark}{\ensuremath{^\mathrm{TM}}}
\ProvideTextCommandDefault{\textflorin}{\textit{f}}
\ProvideTextCommandDefault{\textpeseta}{Pt}
\ProvideTextCommandDefault{\textblacksquare}
   {\vrule \@width .3em \@height .4em \@depth -.1em\relax}
\ProvideTextCommandDefault{\textcent}
   {\TextSymbolUnavailable\textcent}
\ProvideTextCommandDefault{\textyen}
   {\TextSymbolUnavailable\textyen}
\ProvideTextCommandDefault{\textcurrency}
   {\TextSymbolUnavailable\textcurrency}
\ProvideTextCommandDefault{\textbrokenbar}
   {\TextSymbolUnavailable\textbrokenbar}
\providecommand{\mathonesuperior}{{^1}}
\providecommand{\mathtwosuperior}{{^2}}
\providecommand{\maththreesuperior}{{^3}}
\providecommand{\mathnsuperior}{{^n}}
\DeclareInputText{128}{{\c C}}
\DeclareInputText{129}{\"u}
\DeclareInputText{130}{\@tabacckludge'e}
\DeclareInputText{131}{\^a}
\DeclareInputText{132}{\"a}
\DeclareInputText{133}{\@tabacckludge`a}
\DeclareInputText{134}{\r a}
\DeclareInputText{135}{{\c c}}
\DeclareInputText{136}{\^e}
\DeclareInputText{137}{\"e}
\DeclareInputText{138}{\@tabacckludge`e}
\DeclareInputText{139}{\"\i}
\DeclareInputText{140}{\^\i}
\DeclareInputText{141}{\@tabacckludge`\i}
\DeclareInputText{142}{\"A}
\DeclareInputText{143}{\r A}
\DeclareInputText{144}{\@tabacckludge'E}
\DeclareInputText{145}{\ae}
\DeclareInputText{146}{\AE}
\DeclareInputText{147}{\^o}
\DeclareInputText{148}{\"o}
\DeclareInputText{149}{\@tabacckludge`o}
\DeclareInputText{150}{\^u}
\DeclareInputText{151}{\@tabacckludge`u}
\DeclareInputText{152}{\"y}
\DeclareInputText{153}{\"O}
\DeclareInputText{154}{\"U}
\DeclareInputText{155}{\textcent}
\DeclareInputText{156}{\pounds}
\DeclareInputText{157}{\textyen}
\DeclareInputText{158}{\ss} % german sz
\DeclareInputText{159}{\textflorin}
\DeclareInputText{160}{\@tabacckludge'a}
\DeclareInputText{161}{\@tabacckludge'\i}
\DeclareInputText{162}{\@tabacckludge'o}
\DeclareInputText{163}{\@tabacckludge'u}
\DeclareInputText{164}{\~n}
\DeclareInputText{165}{\~N}
\DeclareInputText{166}{\textordfeminine}
\DeclareInputText{167}{\textordmasculine}
\DeclareInputText{168}{\textquestiondown}
\DeclareInputMath{170}{\lnot}
\DeclareInputText{171}{\textonehalf}
\DeclareInputText{172}{\textonequarter}
\DeclareInputText{173}{\textexclamdown}
\DeclareInputText{174}{\guillemotleft}
\DeclareInputText{175}{\guillemotright}
\DeclareInputText{176}{\~a}
\DeclareInputText{177}{\~o}
\DeclareInputText{178}{\O}
\DeclareInputText{179}{\o}
\DeclareInputText{180}{\oe}
\DeclareInputText{181}{\OE}
\DeclareInputText{182}{\@tabacckludge`A}
\DeclareInputText{183}{\~A}
\DeclareInputText{184}{\~O}
\DeclareInputText{185}{\"{}}
\DeclareInputText{186}{\'{}}
\DeclareInputText{187}{\dag}
\DeclareInputText{188}{\P}
\DeclareInputText{189}{\copyright}
\DeclareInputText{190}{\textregistered}
\DeclareInputText{191}{\texttrademark}
\DeclareInputText{221}{\S}
\DeclareInputText{222}{\^{}}
\DeclareInputMath{223}{\infty}
\DeclareInputMath{224}{\alpha}
\DeclareInputMath{225}{\beta}
\DeclareInputMath{226}{\Gamma}
\DeclareInputMath{227}{\pi}
\DeclareInputMath{228}{\Sigma}
\DeclareInputMath{229}{\sigma}
\DeclareInputMath{230}{\mu}
\DeclareInputMath{231}{\gamma}
\DeclareInputMath{232}{\Phi}
\DeclareInputMath{233}{\theta}
\DeclareInputMath{234}{\Omega}
\DeclareInputMath{235}{\delta}
\DeclareInputMath{236}{\infty}
\DeclareInputMath{237}{\phi}
\DeclareInputMath{238}{\varepsilon}
\DeclareInputMath{239}{\cap}
\DeclareInputMath{240}{\equiv}
\DeclareInputMath{241}{\pm}
\DeclareInputMath{242}{\ge}
\DeclareInputMath{243}{\le}
\DeclareInputMath{246}{\div}
\DeclareInputMath{247}{\approx}
\DeclareInputText{248}{\textdegree}
\DeclareInputText{249}{\textperiodcentered}
\DeclareInputText{250}{\textbullet}
\DeclareInputMath{251}{\surd}
\DeclareInputMath{252}{\mathnsuperior}
\DeclareInputMath{253}{\mathtwosuperior}
\DeclareInputText{254}{\maththreesuperior}
\DeclareInputText{255}{\nobreakspace}
\makeatother
\endinput
%%
%% End of file `atari.def'.
