%%
%% This is file `isolatin.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% umlaute.dtx  (with options: `isolatin')
%% 
%% Copyright (C) 1994-2006 Axel Sommerfeldt (caption@sommerfee.de)
%% 
%% --------------------------------------------------------------------------
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2003/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% This Current Maintainer of this work is Axel Sommerfeldt.
%% 
%% This work consists of the files umlaute.ins, umlaute.dtx
%% and the derived files umlaute.sty, atari.def, pc850.def,
%% isolatin.def, mac.def, and roman8.def.
%% 
\ProvidesFile{isolatin.def}[2006/01/29 v2.1 Input encoding file (AS)]
\PackageWarning{umlaute}{%
  This input encoding has been superseeded by the `latin1' encoding}
\input latin1.def
\endinput
%%
%% End of file `isolatin.def'.
